@@ -9,16 +9,17 @@ import matplotlib.pyplot as plt
 
 from .plottools import *
 
-#TODO: CO is currently hardcoded
+#TODO: 
+# CO is currently hardcoded
+# Make better custom band selection
 
 def spec(model, 
         pol=False, 
-        nside=64, 
         sky_fractions=(25,85), 
         xlim=(0.25, 4000),
         long=True,
         darkmode=False, 
-        ame_polfrac=0.02,
+        ame_polfrac=0.006,
         haslam = True,
         chipass = True,
         spass = True,
@@ -31,19 +32,85 @@ def spec(model,
         custom_bands = None,
         include_co=True,
         add_error = True):
-    # TODO, they need to be smoothed to common res!
-    set_style(darkmode, font="dejavusans")
+    """
+    Generates RMS intensity plot for components in model.
+        `model = cosmoglobe.model_from_chain(chain, nside=64, components=["synch", "ff", "ame", "dust", "radio"])`
+        `spec(model)`
+
+
+    Parameters
+    ----------
+    model : cosmoglobe Model object
+        Object containing all sky components to be visualized
+    pol : bool, optional
+        Plot polarization instead of intensity
+        default = None (temperature)
+    sky_fractions : touple, optional
+        Min and max sky fractions for thickness of lines
+        default: (25,85)
+    xlim : touple, optional
+        The limits of the x axis
+        default: (0.25, 4000)
+    long: bool, optional
+        Increases the xlimit and includes an additional subplot on top
+        default: True
+    darkmode : bool, optional
+        Set True to turn all frame elements white for black background viewing.
+        default: False 
+    ame_polfrac: float, optional
+        Set the polarization fraction of AME with a scale factor.
+        default: 0.006
+    haslam : bool, optional
+        Toggle this observation column
+        default:  True
+    chipass : bool, optional
+        Toggle this observation column
+        default:  True
+    spass : bool, optional
+        Toggle this observation column
+        default:  True
+    cbass : bool, optional
+        Toggle this observation column
+        default:  True
+    quijote : bool, optional
+        Toggle this observation column
+        default:  False
+    wmap : bool, optional
+        Toggle this observation column
+        default:  True
+    planck : bool, optional
+        Toggle this observation column
+        default:  True
+    dirbe : bool, optional
+        Toggle this observation column
+        default:  True
+    litebird : bool, optional
+        Toggle this observation column
+        default:  False
+    custom_bands : bool, optional
+        TODO: NOT IMPLEMENTED, toggle specific bands
+        default:  None
+    include_co : bool,  optional
+        Turn off CO lines
+        default: True
+    add_error : bool, optional
+        Toggle added uncertainty to low S/N part of spectrum.
+        default: True
+
+    """
+    
+    set_style(darkmode, font="serif")
     params={
         'xtick.top'          : False,
-        'ytick.right'        : True, #Set to false
-        'axes.spines.top'    : True, #Set to false
+        'ytick.right'        : True, 
+        'axes.spines.top'    : True, 
         'axes.spines.bottom' : True,
         'axes.spines.left'   : True,
-        'axes.spines.right'  : True, #Set to false@
+        'axes.spines.right'  : True,
         'axes.grid.axis'     : 'y',
         'axes.grid'          : False,
         'ytick.major.size'   : 5,
-        'ytick.minor.size'   : 2.6,
+        'ytick.minor.size'   : 2.5,
         'xtick.major.size'   : 5,
         'xtick.minor.size'   : 2.5,
         'xtick.major.pad'    : 8, 
@@ -60,6 +127,7 @@ def spec(model,
     else:
         brokecol=black
         grey="grey"
+        grey="#C0C0C0"
 
     colors=['#636EFA', '#EF553B', '#00CC96', '#AB63FA', '#FFA15A', '#19D3F3', '#FF6692', '#B6E880', '#FF97FF', '#FECB52', grey,]
     rcParams['axes.prop_cycle'] = cycler(color=colors)
@@ -232,6 +300,10 @@ def spec(model,
         TODO: Make it easier to specify which bands to include
         """
         pass 
+    if isinstance(planck, bool):
+        planck=[planck]*9
+    if isinstance(wmap, bool):
+        wmap=[wmap]*5
 
     # TODO add these as args?
     databands = {"Haslam":  {"0.408\nHaslam": {"pol": False, "show": haslam, "position": [.408, ymin*yscaletextup],  "range": [.406,.410], "color": purple,}},
@@ -244,23 +316,23 @@ def spec(model,
                              "19":             {"pol": True, "show": quijote, "position": [20, ymax2*yscaletext], "range":  [18.,21.], "color": red,},
                              ".\n31":             {"pol": True, "show": quijote, "position": [31, ymax2*yscaletext], "range":  [26.,36.], "color": red,},
                              ".\n41":             {"pol": True, "show": quijote, "position": [42, ymax2*yscaletext], "range":  [35.,47.], "color": red,}},
-                 "Planck":  {"30":          {"pol": True, "show": planck, "position": [27,  ymax2*yscaletext], "range": [23.9,34.5],"color": orange,},      # Planck 30
-                             "44":          {"pol": True, "show": planck, "position": [40,  ymax2*yscaletext], "range": [39,50]    ,"color": orange,},      # Planck 44
-                             "70":          {"pol": True, "show": planck, "position": [60,  ymax2*yscaletext], "range": [60,78]    ,"color": orange,},      # Planck 70
-                             "100\nPlanck": {"pol": True, "show": planck, "position": [90,  ymax2*yscaletext], "range": [82,120]   ,"color": orange,},      # Planck 100
-                             "143":         {"pol": True, "show": planck, "position": [130, ymax2*yscaletext], "range": [125,170]  ,"color": orange,},      # Planck 143
-                             "217":         {"pol": True, "show": planck, "position": [195, ymax2*yscaletext], "range": [180,265]  ,"color": orange,},      # Planck 217
-                             "353":         {"pol": True, "show": planck, "position": [320, ymax2*yscaletext], "range": [300,430]  ,"color": orange,},      # Planck 353
-                             "545":         {"pol": False, "show": planck, "position": [490, ymax2*yscaletext], "range": [450,650]  ,"color": orange,},      # Planck 545
-                             "857":         {"pol": False, "show": planck, "position": [730, ymax2*yscaletext], "range": [700,1020] ,"color": orange,}},      # Planck 857
+                 "Planck":  {"30":          {"pol": True, "show": planck[0], "position": [27,  ymax2*yscaletext], "range": [23.9,34.5],"color": orange,},      # Planck 30
+                             "44":          {"pol": True, "show": planck[1], "position": [40,  ymax2*yscaletext], "range": [39,50]    ,"color": orange,},      # Planck 44
+                             "70":          {"pol": True, "show": planck[2], "position": [60,  ymax2*yscaletext], "range": [60,78]    ,"color": orange,},      # Planck 70
+                             "100\nPlanck": {"pol": True, "show": planck[3], "position": [90,  ymax2*yscaletext], "range": [82,120]   ,"color": orange,},      # Planck 100
+                             "143":         {"pol": True, "show": planck[4], "position": [130, ymax2*yscaletext], "range": [125,170]  ,"color": orange,},      # Planck 143
+                             "217":         {"pol": True, "show": planck[5], "position": [195, ymax2*yscaletext], "range": [180,265]  ,"color": orange,},      # Planck 217
+                             "353":         {"pol": True, "show": planck[6], "position": [320, ymax2*yscaletext], "range": [300,430]  ,"color": orange,},      # Planck 353
+                             "545":         {"pol": False, "show": planck[7], "position": [490, ymax2*yscaletext], "range": [450,650]  ,"color": orange,},      # Planck 545
+                             "857":         {"pol": False, "show": planck[8], "position": [730, ymax2*yscaletext], "range": [700,1020] ,"color": orange,}},      # Planck 857
                  "DIRBE":   {"DIRBE\n1250":  {"pol": False, "show": dirbe, "position": [1000, ymin*yscaletextup], "range": [1000,1540] , "color": red,},     # DIRBE 1250
                              "2140":         {"pol": False, "show": dirbe, "position": [1750, ymin*yscaletextup], "range": [1780,2500] , "color": red,},     # DIRBE 2140
                              "3000":         {"pol": False, "show": dirbe, "position": [2500, ymin*yscaletextup], "range": [2600,3500] , "color": red,}},     # DIRBE 3000
-                 "WMAP":    {"K": {"pol": True, "show": wmap, "position": [21.8, ymin*yscaletextup], "range": [21,25.5], "color": teal,}, 
-                             "WMAP\nKa":      {"pol": True, "show": wmap, "position": [31.5, ymin*yscaletextup], "range": [30,37], "color": teal,},
-                             "Q":       {"pol": True, "show": wmap, "position": [39.,  ymin*yscaletextup], "range": [38,45], "color": teal,}, 
-                             "V":       {"pol": True, "show": wmap, "position": [58.,  ymin*yscaletextup], "range": [54,68], "color": teal,}, 
-                             "W":       {"pol": True, "show": wmap, "position": [90.,  ymin*yscaletextup], "range": [84,106], "color": teal,}}, 
+                 "WMAP":    {"K": {"pol": True, "show": wmap[0], "position": [21.8, ymin*yscaletextup], "range": [21,25.5], "color": teal,}, 
+                             "WMAP\nKa":      {"pol": True, "show": wmap[1], "position": [31.5, ymin*yscaletextup], "range": [30,37], "color": teal,},
+                             "Q":       {"pol": True, "show": wmap[2], "position": [39.,  ymin*yscaletextup], "range": [38,45], "color": teal,}, 
+                             "V":       {"pol": True, "show": wmap[3], "position": [58.,  ymin*yscaletextup], "range": [54,68], "color": teal,}, 
+                             "W":       {"pol": True, "show": wmap[4], "position": [90.,  ymin*yscaletextup], "range": [84,106], "color": teal,}}, 
                  "LiteBIRD":  {"40":          {"pol": True, "show": litebird, "position": [40,  ymax2*yscaletext], "range": [34,46],"color": red,}, 
                             "50":          {"pol": True, "show": litebird, "position": [50,  ymax2*yscaletext], "range": [43,57]    ,"color": red,},
                             "60":          {"pol": True, "show": litebird, "position": [60,  ymax2*yscaletext], "range": [53,67]    ,"color": red,},
@@ -312,13 +384,17 @@ def spec(model,
     ax.tick_params(axis='both', which='major', labelsize=lsize, direction='in')
     ax.tick_params(which="both",direction="in")
     ax.tick_params(axis='y', labelrotation=90) 
-    ax.set_yticklabels([fmt(x,1) for x in ax.get_yticks()], va="center")
+    ax.set_yticklabels([fmt(x,1) for x in ax.get_yticks()], va="center", fontsize=lsize)
     if long:
         ax2.set(xscale='log', yscale='log', ylim=(ymin2, ymax2), xlim=(xmin,xmax), yticks=[1e4,1e6,], xticks=ticks, xticklabels=ticks)
         ax2.tick_params(axis='both', which='major', labelsize=lsize, direction='in')
         ax2.tick_params(which="both",direction="in")
         ax2.tick_params(axis='y', labelrotation=90,) 
-        ax2.set_yticklabels([fmt(x,1) for x in ax2.get_yticks()], va="center")
+        ax2.set_yticklabels([fmt(x,1) for x in ax2.get_yticks()], va="center", fontsize=lsize)
+
+    ax.set_xticklabels([fmt(x,1) for x in ax.get_xticks()], fontsize=lsize)
+
+
 
     # Axis labels
     sax = fig.add_subplot(111, frameon=False)
